'use strict';

angular.module('beruby', ['ngAnimate', 'ngCookies', 'ngSanitize', 'ngTouch', 'ngRoute', 'pascalprecht.translate', 'infinite-scroll'])
  .config(["$routeProvider", "$httpProvider", function($routeProvider, $httpProvider) {
    $routeProvider
      .when('/', {
        templateUrl: 'partials/welcome.html',
        controller: 'WelcomeController'
      })
      .when('/login', {
        templateUrl: 'partials/login.html',
        controller: 'LoginController'
      })
      .when('/signup', {
        templateUrl: 'partials/signup.html',
        controller: 'SignupController'
      })
      .when('/search', {
        templateUrl: 'partials/search.html',
        controller: 'SearchController'
      })
      .when('/balance', {
        templateUrl: 'partials/balance.html',
        controller: 'BalanceController'
      })
      .when('/widgets/:id', {
        templateUrl: 'partials/show_widget.html',
        controller: 'ShowWidgetController'
      })
      .when('/widgets', {
        templateUrl: 'partials/widgets_section.html',
        controller: 'WidgetsSectionController'
      })
      .when('/category', {
        templateUrl: 'partials/category.html',
        controller: 'CategoryController'
      })
      .when('/transactions', {
        templateUrl: 'partials/transactions.html',
        controller: 'TransactionsController'
      })
      .otherwise({
        redirectTo: '/'
      });

    $httpProvider.defaults.withCredentials = true;
    $httpProvider.defaults.headers.common['X-MobileVersion'] = '2.1';
    $httpProvider.defaults.cache = false;

    $httpProvider.interceptors.push(["$q", "SessionService", "NavigationService", function($q, SessionService, NavigationService) {
      return {
        responseError: function(rejection) {
          if (rejection.status === 401) {
            SessionService.setLoggedIn(false);
            NavigationService.path('/login', true);
          }

          return $q.reject(rejection);
        }
      };
    }]);
    
  }]).run(["$rootScope", function($rootScope){
    $rootScope.$on('$routeChangeSuccess', function () {
        jQuery(document).foundation('reflow');
    });
  }]).run(["$window", "NavigationService", function($window, NavigationService){
    document.addEventListener('deviceready', function () {
      // Enable to debug issues.
      // $window.plugins.OneSignal.setLogLevel({logLevel: 4, visualLevel: 4});
  
      var notificationOpenedCallback = function(jsonData) {
        console.log('didReceiveRemoteNotificationCallBack: ' + JSON.stringify(jsonData));
        NavigationService.path('/notifications/' + $window.encodeURIComponent(jsonData.additionalData.url));
      };

      //AIzaSyDe50ODkPrWlrpInIaCT6cVZzv95Vdz4rI google gcm api key
      $window.plugins.OneSignal.init(
        'af048a6d-43a6-40b9-9d31-f37448080c04', {googleProjectNumber: '719929336035'},
        notificationOpenedCallback);

      // Show an alert box if a notification comes in when the user is in your app.
      $window.plugins.OneSignal.enableInAppAlertNotification(false);
      $window.plugins.OneSignal.enableNotificationsWhenActive(true);
    }, false);
  }]).run(["$rootScope", "$location", "SessionService", "NavigationService", "Countries", function($rootScope, $location, SessionService, NavigationService, Countries) {
    $rootScope.loadPath = function(path, truncate) {
      NavigationService.url(path, truncate);
    };

    document.addEventListener('deviceready', function(){
      document.addEventListener('backbutton', function(){
        $rootScope.$apply(function(){
          if(!NavigationService.back() && navigator && navigator.app){
            navigator.app.exitApp();
          }
        });
      }, false);
    }, false);

    $rootScope.navigation = {};

    $rootScope.header = {
      image: 'beruby_red.png',
      section: '',
      back: function(){
        NavigationService.back();
      }
    };
    $rootScope.countries = Countries;

    $rootScope.navigateBack = false;
    if(navigator && navigator.userAgent && !navigator.userAgent.match(/android/i)){
      $rootScope.platform = 'ios';
    }
    $rootScope.loading = false;

    $rootScope.layout = {
      bodyBackground: ''
    };

    if (SessionService.isLoggedIn()) {
      NavigationService.url('/search', true);
    } else {
      NavigationService.path('/', true);
    }
  }]);
'use strict';

angular.module('beruby')
  .config(["$translateProvider", function($translateProvider) {
  	$translateProvider.translations('en', {
      search: {
        placeholder: 'Search shops',
        tutorial:  'Search for a store!<br /><br /> Or explore our directory to earn cashback in youn next purchase or travel booking',
        empty: 'Unfortunately we cannot find what you are looking for!  Try to search in our directory'

      },
      sections: {
        balance: 'balance',
        offers: 'offers',
        travels: 'travel',
        shopping: 'shops'
      },
      welcome: {
        start: 'start',
        shopping_title: 'shops',
        travels_title: 'travel',
        offers_title: 'offers',
        shopping_phrase: 'We refund you part of the value of your purchases<br />'+
          '<b>More than 500 online stores</b> to buy.',
        travels_phrase: 'We refund you part of the value of your travel arrangements<br />'+
          '<b>Book through beruby</b> your plane, hotel, car...',
        offers_phrase: 'We refund you part of the value of your purchases<br />'+
          '<b>More than 500 online stores</b> to shop.',
      },
      form: {
        country: 'Country',
        email: 'Email',
        password: 'Password',
        enter: 'Enter',
        no_account: '<b>Need an account?</b><br />Register now and start saving!',
        signup: 'Sign up',
        birth_date: 'Date of birth',
        gender: 'Gender',
        name: 'Name',
        man: 'Male',
        woman: 'Female',
        countries: {
          es: 'España',
          uk: 'United Kingdom',
          us: 'United States',
          pt: 'Portugal',
          br: 'Brasil',
          co: 'Colombia',
          cl: 'Chile',
          ar: 'Argentina',
          mx: 'Mexico',
          it: 'Italia',
          nl: 'Netherland',
          tr: 'Türkiye',
          de: 'Deutschland',
          fr: 'France',
          america: 'America'
        },
        login_error: 'Invalid username or password'
      },
      balance: {
        unconfirmed: 'Unconfirmed balance',
        confirmed: 'Confirmed balance',
        direct: 'Direct',
        network: 'My network',
        transactions: 'Transactions',
        share: 'Share Beruby with your friends'
      },
      widget: {
        visit: 'Visit',
        particular_conditions: 'Particular conditions',
        last_launch_date: 'Last commission',
        last_paid_date: 'Last Payment',
        related: 'Related merchants',
        monetize: 'How to earn cashback',
        products: 'Products and Services',
        concept: 'Action',
        cashback: 'Cashback',
        direct_amount: 'You',
        network_amount: 'Your Network',
        checking_cookies: 'One moment, please...',
        no_cookies: 'Important! Cookies are not enabled in your browser so your purchases will not be tracked.  <a href="http://{{country}}.beruby.com/web/cookies" target="_blank">More info.</a>',
        warning: 'Warning'
      },
      transactions: {
        empty: 'You haven\'t had any activity in the last three months'
      }
    });

    $translateProvider.translations('it', {
      search: {
        placeholder: 'Cercare negozi',
        tutorial: 'Cerca un negozio!<br /><br /> O esplora le nostre categorie per generare cashback con il tuo prossimo acquisto o prenotazione',
        empty: 'Peccato! Non troviamo quello che cerchi! Prova a cercare nelle nostre categorie'
      },
      sections: {
        balance: 'saldo',
        offers: 'offerte',
        travels: 'viaggi',
        shopping: 'acquisti'
      },
      welcome: {
        start: 'iniziare',
        shopping_title: 'acquisti',
        travels_title: 'viaggi',
        offers_title: 'offerte',
        shopping_phrase: 'Ti rimborsiamo una parte del valore dei tuoi acquisti<br />' +
          '<b>Oltre di 600 negozi online</b> in cui comprare.',
        travels_phrase: 'Ti rimborsiamo una parte del valore dei tuoi viaggi<br />' +
          '<b>Prenota attraverso beruby</b> il tuo volo, hotel, automobile, etc.',
        offers_phrase: 'Ti rimborsiamo una parte del valore dei tuoi acquisti<br />' +
          '<b>Oltre di 600 negozi online</b> in cui comprare.',
      },
      form: {
        country: 'Paese',
        email: 'Email',
        password: 'Password',
        enter: 'Entrare',
        no_account: '<b>¿Non hai un account?</b><br />Registrati e comincia a risparmiare!',
        signup: 'Regístrati',
        birth_date: 'Data di nascita',
        gender: 'Sesso',
        name: 'Nome',
        man: 'Uomo',
        woman: 'Donna',
        countries: {
          es: 'España',
          uk: 'United Kingdom',
          us: 'United States',
          pt: 'Portugal',
          br: 'Brasil',
          co: 'Colombia',
          cl: 'Chile',
          ar: 'Argentina',
          mx: 'Mexico',
          it: 'Italia',
          nl: 'Netherland',
          tr: 'Türkiye',
          de: 'Deutschland',
          fr: 'France',
          america: 'America'
        },
        login_error: 'Utente o password non validi'
      },
      balance: {
        unconfirmed: 'Saldo da confermare',
        confirmed: 'Saldo confermato',
        direct: 'Diretto',
        network: 'La mia rete',
        transactions: 'Transazioni',
        share: 'Condividi beruby con i toi amici'
      },
      widget: {
        visit: 'Visitare',
        particular_conditions: 'Condizioni particolari',
        last_launch_date: 'Ultima commissione',
        last_paid_date: 'Ultimo pagamento',
        related: 'inserzionisti Simili',
        products: 'Prodotti e servizi',
        monetize: 'Come risparmiare',
        concept: 'Concetto',
        cashback: 'Cashback',
        direct_amount: 'Tu',
        network_amount: 'La tua rete',
        checking_cookies: 'Un momento per favore...',
        no_cookies: 'Importante! I cookie del tuo browser non sono attivati e i tuoi acquisti non saranno registrati. <a href="http://{{country}}.beruby.com/web/cookies" target="_blank">Ulteriori informazioni.</a>',
        warning: 'Warning'
      },
      transactions: {
        empty: 'Negli ultimi tre mesi non hai richiesto nessun pagamento'
      }
    });

    $translateProvider.translations('br', {
      search: {
        placeholder: 'Procurar lojas',
        tutorial: 'Procurar uma loja!<br /><br /> Ou navegue pelas nossas categorias para gerar um cashback nas sua próxima compra ou reserva',
        empty: 'Que pena! Não encontramos o que você procura! Tente procurar em nossas categorias'
      },
      sections: {
        balance: 'saldo',
        offers: 'ofertas',
        travels: 'viagens',
        shopping: 'compras'
      },
      welcome: {
        start: 'come&ccedil;ar',
        shopping_title: 'compras',
        travels_title: 'viagens',
        offers_title: 'ofertas',
        shopping_phrase: 'Lhe reembolsamos parte do valor das suas compras<br />' +
          '<b>Mais de 250 lojas online</b> onde comprar.',
        travels_phrase: 'Lhe reembolsamos parte do valor das suas viagens<br />' +
          '<b>Reserve atrav&eacute;s de beruby</b> o seu voo, hotel, carro, etc.',
        offers_phrase: 'Lhe reembolsamos parte do valor das suas compras<br />' +
          '<b>Mais de 250 lojas online</b> onde comprar.',
      },
      form: {
        contry: 'País',
        email: 'Email',
        password: 'Senha',
        enter: 'Entrar',
        no_account: '<b>N&atilde;o tem uma conta?</b><br />Registre-se j&aacute; e comece a economizar!',
        signup: 'Registre-se',
        birth_date: 'Data de nascimento',
        gender: 'Sexo',
        name: 'Nome',
        man: 'Homem',
        woman: 'Mulher',
        countries: {
          es: 'España',
          uk: 'United Kingdom',
          us: 'United States',
          pt: 'Portugal',
          br: 'Brasil',
          co: 'Colombia',
          cl: 'Chile',
          ar: 'Argentina',
          mx: 'Mexico',
          it: 'Italia',
          nl: 'Netherland',
          tr: 'Türkiye',
          de: 'Deutschland',
          fr: 'France',
          america: 'America'
        },
        login_error: 'Us&aacute;rio ou senha inv&aacute;lido(s)'
      },
      balance: {
        unconfirmed: 'Saldo por confirmar',
        confirmed: 'Saldo confirmado',
        direct: 'Direto',
        network: 'Minha Rede',
        transactions: 'Transa&ccedil;&otilde;es',
        share: 'Partilha beruby com os teus amigos'
      },
      widget: {
        visit: 'Visitar',
        particular_conditions: 'Condi&ccedil;&otilde;es particulares',
        last_launch_date: '&Uacute;ltima comiss&atilde;o',
        last_paid_date: '&Uacute;ltimo pagamento',
        related: 'Anunciantes relacionados',
        monetize: 'Como ganhar dinheiro',
        products: 'Produtos e serviços',
        concept: 'Conceito',
        cashback: 'Cashback',
        direct_amount: 'Você',
        network_amount: 'Sua Rede',
        checking_cookies: 'Um momento por favor',
        no_cookies: 'Atenção! Os cookies do seu navegador não estão ativados, por esta razão as compras não serão registradas. <a href="http://{{country}}.beruby.com/web/cookies" target="_blank">Mais informações.</a>',
        warning: 'Warning'
      },
      transactions: {
        empty: 'Não há atividade nesta conta nos últimos três meses'
      }
    });

    $translateProvider.translations('pt', {
      search: {
        placeholder: 'Procurar lojas',
        tutorial: 'Procurar uma loja!<br /><br /> Ou navega pelas nossas categorias para gerar um cashback nas tua próxima compra ou reserva',
        empty: 'Que pena! Não encontramos o que procuras! Tenta procurar em nossas categorias'
      },
      sections: {
        balance: 'saldo',
        offers: 'ofertas',
        travels: 'viagens',
        shopping: 'compras'
      },
      welcome: {
        start: 'come&ccedil;ar',
        shopping_title: 'compras',
        travels_title: 'viagens',
        offers_title: 'ofertas',
        shopping_phrase: 'Reembolsamos-te parte do valor das tuas compras<br />' +
          '<b>Mais de 200 lojas online</b> onde comprar.',
        travels_phrase: 'Reembolsamos-te parte do valor das tuas viagens<br />' +
          '<b>Reserva atrav&eacute;s de beruby</b> o teu voo, hotel, carro, etc.',
        offers_phrase: 'Reembolsamos-te parte do valor das tuas compras<br />' +
          '<b>Mais de 200 lojas online</b> onde comprar.',
      },
      form: {
        contry: 'País',
        email: 'Email',
        password: 'Password',
        enter: 'Entrar',
        no_account: '<b>N&atilde;o tens uma conta?</b><br />Registra-te j&aacute; e come&ccedil; a poupar!',
        signup: 'Registra-te',
        birth_date: 'Data de nascimento',
        gender: 'Sexo',
        name: 'Nome',
        man: 'Homem',
        woman: 'Mulher',
        countries: {
          es: 'España',
          uk: 'United Kingdom',
          us: 'United States',
          pt: 'Portugal',
          br: 'Brasil',
          co: 'Colombia',
          cl: 'Chile',
          ar: 'Argentina',
          mx: 'Mexico',
          it: 'Italia',
          nl: 'Netherland',
          tr: 'Türkiye',
          de: 'Deutschland',
          fr: 'France',
          america: 'America'
        },
        login_error: 'Usu&aacute;rio ou password inv&aacute;lido(s)'
      },
      balance: {
        unconfirmed: 'Saldo por confirmar',
        confirmed: 'Saldo confirmado',
        direct: 'Directo',
        network: 'Minha Rede',
        transactions: 'Transac&ccedil;&otilde;es',
        share: 'Partilha beruby com os teus amigos'
      },
      widget: {
        visit: 'Visitar',
        particular_conditions: 'Condi&ccedil;&otilde;es particulares',
        last_launch_date: '&Uacute;ltima comiss&atilde;o',
        last_paid_date: '&Uacute;ltimo pagamento',
        related: 'Anunciantes relacionados',
        monetize: 'Como poupar dinheiro',
        products: 'Produtos e serviços',
        concept: 'Conceito',
        cashback: 'Cashback',
        direct_amount: 'Tu',
        network_amount: 'A tua Rede',
        checking_cookies: 'Um momento por favor... ',
        no_cookies: 'Atenção! Os cookies do teu navegador não estão activados, por esta razão as compras não serão registadas. <a href="http://{{country}}.beruby.com/web/cookies" target="_blank">Mais informações.</a>',
        warning: 'Warning'
      },
      transactions: {
        empty: 'Não existe actividade nesta conta nos últimos três meses'
      }
    });

    $translateProvider.translations('tr', {
      search: {
        placeholder: 'Mağaza ara',
        tutorial: 'Sevdiğin mağazayı ara!<br /><br /> Ya da bir sonraki alışveriş ya da rezervasyonunuzda para iadesi kazanmak için kategorilerimizi gez',
        empty: 'Uff! Aradığını bir türlü bulamıyoruz! Bir de kategorilerimizi inceleyerek bulmayı dene'
      },
      sections: {
        balance: 'bakiye',
        offers: 'fırsatlar',
        travels: 'seyahat',
        shopping: 'alışveriş'
      },
      welcome: {
        start: 'alışverişe başla',
        shopping_title: 'alışveriş',
        travels_title: 'seyahat',
        offers_title: 'fırsatlar',
        shopping_phrase: 'Harcamalarının bir kısmını sana iade ediyoruz<br />' +
          'Alışveriş yapabileceğin <b>300+ online mağaza</b>',
        travels_phrase: 'Seyahat harcamalarının bir kısmını sana iade ediyoruz<br />' +
          '<b>beruby üzerinden</b> uçak bileti al, otel rezervasyonu yap, araç kirala',
        offers_phrase: 'Harcamalarının bir kısmını sana iade ediyoruz<br />' +
          'Alışveriş yapabileceğin <b>300+ online mağaza</b> ',
      },
      form: {
        contry: 'Ülke',
        email: 'Email',
        password: 'Şifre',
        enter: 'giriş',
        no_account: '<b>beruby hesabın yok mu?</b><br />Hemen üye ol ve kazanmaya başla!',
        signup: 'Üye ol',
        birth_date: 'Doğum Tarihi',
        gender: 'Cinsiyet',
        name: 'İsim',
        man: 'Erkek',
        woman: 'Kadın',
        countries: {
          es: 'España',
          uk: 'United Kingdom',
          us: 'United States',
          pt: 'Portugal',
          br: 'Brasil',
          co: 'Colombia',
          cl: 'Chile',
          ar: 'Argentina',
          mx: 'Mexico',
          it: 'Italia',
          nl: 'Netherland',
          tr: 'Türkiye',
          de: 'Deutschland',
          fr: 'France',
          america: 'America'
        },
        login_error: 'Kullanıcı adı ya da şifre yanlış'
      },
      balance: {
        unconfirmed: 'Onay bekleyen bakiye',
        confirmed: 'Onaylanmış bakiye',
        direct: 'Direkt',
        network: 'Ağım',
        transactions: 'İşlemlerim',
        share: 'beruby´yi arkadaşlarına öner'
      },
      widget: {
        visit: 'Ziyaret et',
        particular_conditions: 'Özel durumlar',
        last_launch_date: 'Son komisyon',
        last_paid_date: 'Son ödeme',
        related: 'İlgili mağazalar',
        products: 'Ürün ve Hizmetler',
        monetize: 'Nasıl para kazanırım',
        concept: 'Kavram',
        cashback: 'Para iadesi',
        direct_amount: 'Sen',
        network_amount: 'Ağınız',
        checking_cookies: 'Bir dakika lütfen...',
        no_cookies: 'Önemli! Çerez ayarların etkin değil bu yüzden alışverişlerin işlenmeyecek! <a href="http://{{country}}.beruby.com/web/cookies" target="_blank">Daha fazla bilgi</a>',
        warning: 'Warning'
      },
      transactions: {
        empty: 'Son üç aydır hesabında bir hareket yok'
      }
    });

  	$translateProvider.translations('es', {
  		search: {
        placeholder: 'Buscar tiendas',
        tutorial: '¡Busca una tienda!<br /><br /> O explora nuestras categorías para generar cashback en tu próxima compra o reserva',
        empty: '¡Qué pena! ¡No encontramos lo que buscas! Prueba a buscar en nuestras categorías'
      },
      sections: {
        balance: 'saldo',
        offers: 'ofertas',
        travels: 'viajes',
        shopping: 'compras'
      },
      welcome: {
        start: 'empezar',
        shopping_title: 'compras',
        travels_title: 'viajes',
        offers_title: 'ofertas',
        shopping_phrase: 'Te reembolsamos parte del valor de tus compras<br />' +
          '<b>M&aacute;s de 600 tiendas online</b> en las que comprar.',
        travels_phrase: 'Te reembolsamos parte del valor de tus viajes<br />' +
          '<b>Reserva a trav&eacute;s de beruby</b> tu avi&oacute;n, hotel, coche, etc.',
        offers_phrase: 'Otras formas <b>de ahorrar dinero</b><br />' +
          '(visitas, cupones, registros, vídeos...)',
      },
      form: {
        country: 'País',
        email: 'Email',
        password: 'Contraseña',
        enter: 'Entrar',
        no_account: '<b>¿No tienes una cuenta?</b><br />Reg&iacute;strate ya y ¡empieza a ahorrar!',
        signup: 'Regístrate',
        birth_date: 'Fecha de nacimiento',
        gender: 'Sexo',
        name: 'Nombre',
        man: 'Hombre',
        woman: 'Mujer',
        countries: {
          es: 'España',
          uk: 'United Kingdom',
          us: 'United States',
          pt: 'Portugal',
          br: 'Brasil',
          co: 'Colombia',
          cl: 'Chile',
          ar: 'Argentina',
          mx: 'Mexico',
          it: 'Italia',
          nl: 'Netherland',
          tr: 'Türkiye',
          de: 'Deutschland',
          fr: 'France',
          america: 'America'
        },
        login_error: 'Usuario o contraseña inválido(s)'
      },
      balance: {
        unconfirmed: 'Saldo por confirmar',
        confirmed: 'Saldo confirmado',
        direct: 'Directo',
        network: 'Mi Red',
        transactions: 'Transacciones',
        share: 'Comparte Beruby con tus amigos'
      },
      widget: {
        visit: 'Visitar',
        particular_conditions: 'Condiciones particulares',
        last_launch_date: 'Última comisión',
        last_paid_date: 'Último pago',
        related: 'Anunciantes relacionados',
        products: 'Productos y servicios',
        monetize: 'Cómo ganar dinero',
        concept: 'Concepto',
        cashback: 'Cashback',
        direct_amount: 'Tú',
        network_amount: 'Tu Red',
        checking_cookies: 'Un momento por favor... ',
        no_cookies: '¡Importante! Las cookies de tu navegador no están activadas por lo que las compras no se computarán. <a href="http://{{country}}.beruby.com/web/cookies" target="_blank">Más información.</a>',
        warning: 'Utilizar la app de la tienda en vez del navegador de tu móvil podrá hacer que pierdas tu cashback'
      },
      transactions: {
        empty: 'No has tenido actividad en la cuenta en los últimos tres meses'
      }
	  });

    var language = navigator.language.split('-')[0];
    try{
      $translateProvider.use(language);
    }catch(e){
      $translateProvider.use('es');
    }
  }]);
'use strict';

angular.module('beruby')
  .controller('WelcomeController', ["$scope", "$window", "$timeout", "NavigationService", function ($scope, $window, $timeout, NavigationService) {
    if($window.localStorage.welcomeDone === 'yes'){
      NavigationService.path('/login', true);
    }

  	$scope.welcome =  {
      animate: 'animate-left',
  		currentId: 0,
  		slides: [
  			{name: 'shopping', id: 0},
  			{name: 'travels', id: 1},
  			{name: 'offers', id: 2}
  		],
  	};

    $scope.welcome.submit = function(){
      $window.localStorage.welcomeDone = 'yes';
      NavigationService.path('/login', true);
    };

    $scope.welcome.swipeRight = function(){
      $scope.welcome.animate = 'animate-right';
      $scope.welcome.currentId -= 1;
      if($scope.welcome.currentId < 0){
        $scope.welcome.currentId = 0;
      }
    };

    $scope.welcome.swipeLeft = function(){
      $scope.welcome.animate = 'animate-left';
      $scope.welcome.currentId += 1;
      if($scope.welcome.currentId > 2){
        $scope.welcome.currentId = 2;
      }
    };
  }]);

'use strict';

angular.module('beruby')
  .controller('LoginController', ["$scope", "$http", "$translate", "$timeout", "BerubyService", "SessionService", "NavigationService", function ($scope, $http, $translate, $timeout, BerubyService, SessionService, NavigationService) {
    if(SessionService.isLoggedIn()){
      NavigationService.path('/search', true);
    }

    $http.get('http://ipinfo.io').success(function(response) {
        var country_code = response.country;
        var index = $scope.countries.indexOf(country_code.toLowerCase()+'');
        $scope.login.country = $scope.countries[index];
    });
  
    
  	$scope.login = {
      errors: [],
      loading: false
  	};

    function showError(){
      $scope.login.errors.push('error');
    }
  	$scope.login.submit = function(){
      $scope.login.errors = [];

  		var country = $scope.login.country;
  		var email = $scope.login.email;
  		var password = $scope.login.password;

      $scope.loading = true;
  		BerubyService.login(country, email, password).then(function(){
        SessionService.setLoggedIn(true);
        NavigationService.path('/search', true);
  		}).catch(function(){
        try{ga('send', 'event', 'login', 'success');}catch(e){console.log(e);}
        showError($translate.instant('form.login_error'));
  		}).finally(function(){
        try{ga('send', 'event', 'login', 'error');}catch(e){console.log(e);}
        $scope.loading = false;
      });
  	};
  }]);

'use strict';

angular.module('beruby')
  .controller('SignupController', ["$scope", "BerubyService", "NavigationService", function ($scope, BerubyService, NavigationService) {
  	$scope.signup = {
  		errors: {}
  	};

    var signupCountries = [];
    for(var i = 0;i<$scope.countries.length;i++){
      if($scope.countries[i] !== 'uk' && $scope.countries[i] !== 'nl'){
        signupCountries.push($scope.countries[i]);
      }
    }
    $scope.countries = signupCountries;

  	$scope.signup.submit = function(){
  		BerubyService.signup({
  			user: {
  				email: $scope.signup.email,
  				name: $scope.signup.name,
  				password: $scope.signup.password,
  				birth_date: $scope.signup.birthDate,
  				gender: $scope.signup.gender

  			}, country: $scope.signup.country
  		}).then(function(){
        try{ga('send', 'event', 'signup', 'success');}catch(e){console.log(e);}
        NavigationService.path('/search', true);
  		}).catch(function(reason){
        try{ga('send', 'event', 'signup', 'error');}catch(e){console.log(e);}
  			if(reason.response === 'error'){
  				$scope.signup.errors = reason.errors;
  			}
  		});
  	};
  }]);

'use strict';

angular.module('beruby')
  .controller('SearchController', ["$scope", "$routeParams", "BerubyService", "OneSignalService", "NavigationService", function ($scope, $routeParams, BerubyService, OneSignalService, NavigationService) {
  	var query = null;
  	var nextPage = 1;
    var hasMorePages = true;
  	$scope.navigation.active = 'search';
  	$scope.search = {
  		widgets: [],
      fetchingPage: false,
      empty: false,
      hideMessage: false
  	};
    $scope.header.section = '';
    
    BerubyService.getUserInfo().then(function(data){
      OneSignalService.pushTags(data);
    }).catch(function(){});

    $scope.search.submit = function(){
      if($scope.query !== undefined){
        NavigationService.url('/search?query=' + $scope.query);
      }
    };

    function appendWidgets(widgets){
      widgets.forEach(function(widget){
        $scope.search.widgets.push(widget);
      });
    }

    $scope.fetchNextPage = function(){
      if(query === undefined || !hasMorePages || $scope.search.fetchingPage){
        return;
      }

      $scope.search.fetchingPage = true;
      BerubyService.search(query, nextPage)
        .then(function(data){
          if(data.widgets.length > 0){
            $scope.search.empty = false;
            appendWidgets(data.widgets);
          }else{
            $scope.search.empty = true;
          }

          if(data.next_page !== null){
            nextPage = data.next_page;
          }else{
            hasMorePages = false;
          }

        }).catch(function(){
          hasMorePages = false;
        }).finally(function(){
          $scope.search.fetchingPage = false;
        });
    };

    query = $routeParams.query;
    if(query !== undefined){
      $scope.search.hideMessage = true;
      $scope.fetchNextPage();
      $scope.query = query;
      $scope.navigateBack = true;
    }




    $scope.homeWidgets = [];
    var page = 0;
    var haveMorePages = true;
    var waitingForQuery = false;

    function appendHomeWidgets(homeWidgets){
      homeWidgets.forEach(function(homeWidget){
         $scope.homeWidgets.push(homeWidget);
      });
    }

    function fetchNextPage(){
      if(haveMorePages === false || waitingForQuery){
        return;
      }

      $scope.fetchingPage = true;
      page += 1;
      waitingForQuery = true;
      BerubyService.getWidgets(page).then(function(data){
        haveMorePages = false;
        if(data.length > 0){
          appendHomeWidgets(data);

        }else{
          haveMorePages = false;
          if(page === 1){
            $scope.homeWidgetsEmpty = true;
          }
        }
      }).finally(function(){
        $scope.loading = false;
        waitingForQuery = false;
        $scope.fetchingPage = false;
      });
    }

    $scope.fetchNextPage = fetchNextPage;
}]);
'use strict';

angular.module('beruby')
  .controller('BalanceController', ["$scope", "$window", "$translate", "BerubyService", function ($scope,$window, $translate, BerubyService) {
  	$scope.navigation.active = 'balance';
    $scope.header.section = $translate.instant('sections.balance');
  	$scope.balance = {
  		direct: {
  		},
  		network:{
  		} 
  	};



  	$scope.loading = true;
  	BerubyService.getBalance().
  		then(function(data){
  			$scope.balance.network.unconfirmed = data.amount.network[1];
  			$scope.balance.network.confirmed = data.amount.network[2];
  			$scope.balance.direct.unconfirmed = data.amount.direct[1];
  			$scope.balance.direct.confirmed = data.amount.direct[2];
  			$scope.balance.avatarPath = data.avatar_path;
  			$scope.balance.totalAmountText = data.total_amount_text;
  			$scope.balance.totalAmount = data.total_amount;
  			$scope.balance.userName = data.user_name;
  			$scope.balance.promocode = data.promocode_url;

  		}).finally(function(){
  			$scope.loading = false;
  		});

    $scope.open_fb = function(){
      $window.open('http://www.facebook.com/sharer.php?u='+ $scope.balance.promocode + '&t=Beruby', '_system');
    };
    $scope.open_ws = function(){
      $window.open('whatsapp://send?text='+$scope.balance.promocode , '_system');

    };
  }]);

'use strict';

angular.module('beruby')
  .controller('ShowWidgetController', ["$scope", "$route", "$routeParams", "$window", "$translate", "SessionService", "BerubyService", function ($scope, $route, $routeParams, $window, $translate, SessionService, BerubyService) {
    $scope.loading = true;
    $scope.navigateBack = true;
    
    var widgetId = $routeParams.id;
    $scope.widget = {
      section: $routeParams.section,
    };

    function cleanNewLines(text){
      if(text && text.length > 0){
        return text.replace(/^- /, '')
          .replace(/\r\n/g, '\n')
          .replace(/\n-/g, '\n')
          .replace(/\n/g, '<br />');
      }
    }

    BerubyService.getWidget(widgetId).then(function(data){
      $scope.widget.name = data.name;
      $scope.widget.payment = data.payment;
      $scope.widget.imagePath = data.image_path;
      $scope.widget.summary = cleanNewLines(data.desc_summary);
      $scope.widget.products = cleanNewLines(data.desc_products);
      $scope.widget.monetize = cleanNewLines(data.desc_monetize);
      $scope.widget.url = data.url;
      $scope.widget.moreInfo = data.more_info;
      $scope.widget.lastPaidDate = data.last_paid_date;
      $scope.widget.lastLaunchDate = data.last_launch_date;
      $scope.widget.related = cleanNewLines(data.related);
      $scope.widget.particularConditions = cleanNewLines(data.particular_conditions);
      $scope.widget.particularConditions = cleanNewLines(data.particular_conditions);
      $scope.widget.commission = data.commission;
      $scope.widget.earnings = data.earnings;
      $scope.widget.type = data.type;
      $scope.widget.earningsTitle = data.earnings_title;
        

    }).finally(function(){
      $scope.loading = false;
    });

    $scope.visit = function(){
      BerubyService.getOTP().then(function(otp){
        BerubyService.createClickAccount(widgetId).finally(function(){
          var url = $scope.widget.url;
          var match = url.match(/(.*)otp=.*return_to(.*)/);
          var newUrl = match[1] + 'otp=' + otp.code + '&return_to' + match[2];

          try{ga('send', 'pageview', '/visit/' + widgetId);}catch(e){console.log(e);}
          $window.open(newUrl, '_system');
        });
      });
    };
  }]);

'use strict';

angular.module('beruby')
  .controller('WidgetsSectionController', ["$scope", "$routeParams", "$translate", "BerubyService", function ($scope, $routeParams, $translate, BerubyService) {
    
  	var section = $routeParams.section;
    $scope.header.section = $translate.instant('sections.' + section);
  	$scope.section = {
  		name: section,
  		categories: []
  	};

  	$scope.navigation.active = section;

  	$scope.loading = true;
  	BerubyService.getCategoriesForSection(section).then(function(data){
  		$scope.section.categories = data;
  	}).finally(function(){
		  $scope.loading = false;
  	});

  }]);
'use strict';

angular.module('beruby')
  .controller('CategoryController', ["$scope", "$routeParams", "BerubyService", function ($scope, $routeParams, BerubyService) {
    var hasMorePages = true;
    var nextPage = 1;
    $scope.navigateBack = true;

  	$scope.category = {
  		section: $routeParams.section,
      fetchingPage: false,
      widgets: []
  	};

    function appendWidgets(widgets){
      widgets.forEach(function(widget){
        $scope.category.widgets.push(widget);
      });
    }

    $scope.fetchNextPage = function(){
      if(!hasMorePages || $scope.category.fetchingPage){
        return;
      }

      $scope.category.fetchingPage = true;
      $scope.loading = true;
      BerubyService.getWidgetsForUrl($routeParams.url, nextPage).then(function(data){
        if(data.widgets.length > 0){
          appendWidgets(data.widgets);
          nextPage = data.page + 1;
        }else{
          hasMorePages = false;
        }
      }).catch(function(){
        hasMorePages = false;
      }).finally(function(){
        $scope.loading = false;
        $scope.category.fetchingPage = false;
      });
    };

    $scope.fetchNextPage();
  }]);
'use strict';

angular.module('beruby')
  .controller('TransactionsController', ["$scope", "BerubyService", function ($scope, BerubyService) {
  	$scope.loading = true;
  	$scope.transactions = [];
    $scope.header.image = 'beruby_balance.png';
    $scope.navigateBack = true;
    $scope.transactionsEmpty = false;
    $scope.fetchingPage = false;

    var page = 0;
    var haveMorePages = true;
    var waitingForQuery = false;

    function appendTransactions(transactions){
      transactions.forEach(function(transaction){
        $scope.transactions.push(transaction);
      });
    }

    function fetchNextPage(){
      if(haveMorePages === false || waitingForQuery){
        return;
      }

      $scope.fetchingPage = true;
      page += 1;
      waitingForQuery = true;
      BerubyService.getTransactions(page).then(function(data){
        if(data.transactions.length > 0){
          appendTransactions(data.transactions);
        }else{
          haveMorePages = false;
          if(page === 1){
            $scope.transactionsEmpty = true;
          }
        }
      }).finally(function(){
        $scope.loading = false;
        waitingForQuery = false;
        $scope.fetchingPage = false;
      });
    }

    $scope.fetchNextPage = fetchNextPage;
}]);
'use strict';

angular.module('beruby')
  .constant('Countries',
    ['es', 'it', 'pt', 'br', 'america', 'de', 'fr', 'tr']
  );
'use strict';

angular.module('beruby')
  .factory('BerubyService', ["$http", "$location", "$q", "SessionService", function ($http, $location, $q, SessionService) {

    function getBaseUrl(country){
      if(country === undefined){
        country = SessionService.getCountry();
        try{ga('set', 'dimension1', country);}catch(e){console.log(e);}
      }

      if($location.$$host === 'localhost' && false){
        return 'http://es.beruby.dev:3003';
      }else{
        return 'http://' + country + '.beruby.com';
      }
    }

  	var service = {
      signup: function(userData){
        var deferred = $q.defer();
        var country = userData.country;
        if(country === undefined){
          deferred.reject();
          return;
        }

        delete userData.country;
        var birthDate = userData.user.birth_date;
        if(birthDate !== undefined){
          if(typeof birthDate === 'string'){
            var tokens = birthDate.split('-');
            delete userData.user.birth_date;
            userData.user['birth_date(1i)'] = tokens[0];
            userData.user['birth_date(2i)'] = tokens[1];
            userData.user['birth_date(3i)'] = tokens[2];
          }else if(typeof birthDate === 'object'){
            userData.user['birth_date(1i)'] = birthDate.getFullYear();
            userData.user['birth_date(2i)'] = birthDate.getMonth();
            userData.user['birth_date(3i)'] = birthDate.getDate();
          }
        }

        $http.get(getBaseUrl(country) + '/users/token').success(function(data){
          userData.authenticity_token = data.token;

          $http.post(getBaseUrl(country) + '/users',
            userData).success(function(data){
              SessionService.setCountry(country);
              SessionService.setLoggedIn(true);

              return deferred.resolve(data);
            }).error(function(reason){
              return deferred.reject(reason);
            });

        }).error(function(reason){
          return deferred.reject(reason);
        });

        return deferred.promise;
      },
  		login: function(country, email, password){
        var deferred = $q.defer();
        var base = getBaseUrl(country);
        var path = '/account/simple_login';
        if(!base.match(/es.beruby.dev/)){
          base = base.replace(/http/, 'https');
          path = '/account/simple_login_ssl?timestamp=1';
        }

        if(country === undefined){
          deferred.reject();
          return;
        }

  			$http.post(base + path,
  				{email: email, password: password}, {cache: false}).success(function(data){
            SessionService.setCountry(country);
            SessionService.setLoggedIn(true);

  					return deferred.resolve(data);
  				}).error(function(reason){
            return deferred.reject(reason);
          });

  				return deferred.promise;
      }, getTransactions: function(page){
        var deferred = $q.defer();
        var base = getBaseUrl();
        if(!base.match(/es.beruby.dev/)){
          base = base.replace(/http/, 'https');
        }

        $http.get(base + '/users/transactions', {params: {page: page}}).success(function(data){
            return deferred.resolve(data);
          }).error(function(reason){
            return deferred.reject(reason);
          });
          
        return deferred.promise;
      }, getWidgets: function(){
        var deferred = $q.defer();
        $http.get(getBaseUrl() + '/api/mobile_widgets?format=json').success(function(data){
            return deferred.resolve(data);
          }).error(function(reason){
            return deferred.reject(reason);
          });
          
        return deferred.promise;  
      }, search: function(query, page){
        var deferred = $q.defer();
        $http.get(getBaseUrl() + '/portal/search',
          {params: {search: query, target: 'widgets', page: page}}).success(function(data){
            return deferred.resolve(data);
          }).error(function(reason){
            return deferred.reject(reason);
          });

          return deferred.promise;
      }, getBalance: function(){
        var deferred = $q.defer();
        var base = getBaseUrl();
        if(!base.match(/es.beruby.dev/)){
          base = base.replace(/http/, 'https');
        }

        $http.get(base + '/users/balance').success(function(data){
            return deferred.resolve(data);
          }).error(function(reason){
            return deferred.reject(reason);
          });

          return deferred.promise;
      }, getWidget: function(widgetId){
        var deferred = $q.defer();
        
        $http.get(getBaseUrl() + '/advertisers/advertiser_info/' + widgetId).success(function(data){
            return deferred.resolve(data);
          }).error(function(reason){
            return deferred.reject(reason);
          });

          return deferred.promise;
      }, getCategoriesForSection: function(section){
        var path = null;
        if(section === 'shopping'){
          path = '/advertisers/mobile_shopping_sections'; 
        }else if(section === 'travels'){
          path = '/advertisers/mobile_travel_sections';
        }else if(section === 'offers'){
          path = '/advertisers/mobile_offers_sections';
        }
        var deferred = $q.defer();
        $http.get(getBaseUrl() + path).success(function(data){
            return deferred.resolve(data);
          }).error(function(reason){
            return deferred.reject(reason);
          });

          return deferred.promise;
      }, getWidgetsForUrl: function(url, page){
        var deferred = $q.defer();
        $http.get(url, {params: {page: page}}).success(function(data){
            return deferred.resolve(data);
          }).error(function(reason){
            return deferred.reject(reason);
          });

          return deferred.promise;
      }, createClickAccount: function(widgetId){
        var deferred = $q.defer();
        
        $http.get(getBaseUrl() + '/portal/mobile_click_account',
            {params: {widget_id: widgetId}})
          .success(function(data){
            return deferred.resolve(data);
          }).error(function(reason){
            return deferred.reject(reason);
          });

          return deferred.promise;
  		}, getOTP: function(){
        var deferred = $q.defer();
        
        $http.get(getBaseUrl() + '/account/generate_otp')
          .success(function(data){
            return deferred.resolve(data);
          }).error(function(reason){
            return deferred.reject(reason);
          });

          return deferred.promise;
      }, getUserInfo: function(){
        var deferred = $q.defer();

        $http.get(getBaseUrl() + '/account/info').success(function(data){
          return deferred.resolve(data);
        }).error(function(reason){
          return deferred.reject(reason);
        });

        return deferred.promise;
      }
  	};

  	return service;
  }]);
'use strict';

angular.module('beruby')
  .factory('SessionService', ["$window", function ($window) {

  	var loggedIn = false;

  	return {
  		isLoggedIn: function(){
        if(!loggedIn){
          loggedIn = $window.localStorage.loggedIn === 'yes';
        }

  			return loggedIn;
  		}, setLoggedIn: function(state){
        $window.localStorage.loggedIn = state ? 'yes' : 'no';
  			loggedIn = state;
  		}, getCountry: function(){
        return $window.localStorage.country;
      }, setCountry: function(country){
        $window.localStorage.country = country;
      }
  	};
}]);
'use strict';

angular.module('beruby')
  .factory('OneSignalService', ["$window", function ($window) {
    var service = {
        pushTags: function(data){
            $window.plugins.OneSignal.sendTags(data);
        }
    };

    return service;
}]);
'use strict';

angular.module('beruby')
	.service('NavigationService', ["$rootScope", "$location", "$timeout", function($rootScope, $location, $timeout) {
		this.stack = [];
		this.path = function(path, truncate) {
			if (truncate) {
				this.clear();
			}

			this.stack.push(['path', path]);
			try{
				ga('send', 'pageview', path);
			}catch(e){
				console.log(e);
				$timeout(function(){
			    	try{ga('send', 'pageview', path);}catch(e){console.log(e);}
			    }, 4000);
			}
			$location.path(path);
		};

		this.url = function(url, truncate) {
			if (truncate) {
				this.clear();
			}

			this.stack.push(['url', url]);
			try{
				ga('send', 'pageview', url);
			}catch(e){
				console.log(e);
				$timeout(function(){
			    	try{ga('send', 'pageview', url);}catch(e){console.log(e);}
			    }, 4000);
			}
			$location.url(url);
		};

		this.clear = function() {
			this.stack.length = 0;
		};

		this.back = function() {
			if (this.stack.length > 1) {
				this.stack.pop();
				var newLocation = this.stack.pop();				
				switch (newLocation[0]) {
					case 'url':
						this.url(newLocation[1]);
						break;
					case 'path':
						this.path(newLocation[1]);
						break;
				}

				return true;
			} else {
				return false;
			}
		};
	}]);
'use strict';

angular.module('beruby')
	.service('CookiesCheckerService', ["$q", "$cookies", function($q, $cookies) {

	var CookiesChecker = function(){
	};

	CookiesChecker.prototype.checkCookies = function(){
		var deferred = $q.defer();

		var self = this;
		self.checkLocalCookies(deferred);
		self.checkThirdPartyCookies(deferred);

		return deferred.promise;
	};

	CookiesChecker.prototype.checkLocalCookies = function(deferred){
		var date = new Date();
		$cookies.put('somecookie', date.getTime());
		if($cookies.get('somecookie') !== date.getTime()){
			deferred.reject('localCookies');
		}

		$cookies.remove('somecookie');

		return deferred;
	};

	CookiesChecker.prototype.checkThirdPartyCookies = function(deferred){
		var image = new Image();
		image.onerror = function(){
			deferred.reject('connectionError');
		};

		image.onload = function(){
			var image2 = new Image();
			image2.onerror = function(){
				deferred.reject('thirdCookies');
			};

			image2.onload = function(){
				deferred.resolve(true);
			};

			image2.src = 'http://es.mirubi.com/check_cookie';
		};
		image.src = 'http://es.mirubi.com/set_cookie';
	};

	return new CookiesChecker();
}]);

'use strict';

var app = angular.module('beruby');
app.filter('encodeURIComponent', ["$window", function($window) {
    return $window.encodeURIComponent;
}]);
(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/balance.html',
    '<div id="balance" class="contains-navigation"><ng-include src="\'partials/header.html\'"></ng-include><br><div class="content"><div class="row"><div class="small-3 columns"><img ng-src="{{balance.avatarPath}}" class="avatar" ng-show="balance.avatarPath"></div><div class="small-9 columns"><p class="user-name">{{balance.userName}}</p><p class="total-balance">{{balance.totalAmountText}} <span ng-bind-html="balance.totalAmount" class="total-amount"></span></p></div></div><br><div class="row"><table class="small-12 columns" role="grid"><thead><tr><th></th><th translate="balance.unconfirmed"></th><th translate="balance.confirmed"></th></tr></thead><tbody><tr><td translate="balance.direct"></td><td ng-bind-html="balance.direct.unconfirmed"></td><td ng-bind-html="balance.direct.confirmed"></td></tr><tr><td translate="balance.network"></td><td ng-bind-html="balance.network.unconfirmed"></td><td ng-bind-html="balance.network.confirmed"></td></tr></tbody></table></div><div class="row"><div class="small-12 columns"><a ng-click="loadPath(\'/transactions\');" class="transactions-button" translate="balance.transactions"></a></div></div><div class="row"><div class="small-12 columns"><div translate="balance.share" style="padding-bottom: 2rem;text-align: center;"></div></div></div><div class="row"><div ng-click="open_fb();" class="small-4 columns" style="text-align:center;"><img style="height: 50px;" ng-src="images/fb_icon_100.png"></div><div class="small-4 columns" style="text-align:center;"><a ng-href="http://twitter.com/share?url={{balance.promocode}}&text=Beruby" target="_blank"><img style="height: 50px;" ng-src="images/twitter_icon_100.png"></a></div><div ng-click="open_ws();" class="small-4 columns" style="text-align:center;"><img style="height: 50px;" ng-src="images/whatsapp_icon_100.png"></div></div></div><ng-include src="\'partials/navigation.html\'"></ng-include></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/category.html',
    '<div id="category" class="contains-navigation section-{{category.section}}"><ng-include src="\'partials/header.html\'"></ng-include><div class="widgets" infinite-scroll="fetchNextPage()" infinite-scroll-distance="1"><a class="row collapse widget" ng-click="loadPath(\'/widgets/{{widget.id}}?section={{category.section}}\');" ng-repeat="widget in category.widgets"><div class="small-2 columns text-center logo-container" style="display:table;height: 60px;"><div style="display:table-cell; vertical-align:middle;"><img ng-src="http://es.beruby.com/{{widget.image_path}}" class="logo"></div></div><div class="small-7 columns" style="display:table;height: 60px;padding-left:1rem;"><div style="display:table-cell; vertical-align:middle;"><p class="name">{{widget.name}}</p></div></div><div class="small-3 columns" style="display:table;height: 60px;"><div style="display:table-cell; vertical-align:middle;text-align: right;"><p class="commission" ng-bind-html="widget.payment"></p></div></div></a><div class="loading-balls" ng-show="category.fetchingPage"><span class="ball ball-1"></span> <span class="ball ball-2"></span></div></div><ng-include src="\'partials/navigation.html\'"></ng-include></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/header.html',
    '<div id="beruby-header" class="row collapse"><div class="small-12 columns"><a class="left back" ng-show="navigateBack &amp;&amp; platform === \'ios\'" ng-click="header.back();">&lt;</a> <span class="beruby-container"><span class="start">be</span><span class="end">ruby</span> <span class="section">{{header.section}}</span></span></div><div id="loading-bar" ng-show="loading"></div></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/login.html',
    '<div id="login" class="row"><div id="loading-bar" ng-show="login.loading"></div><div class="small-12 columns"><a href="#/"><img src="images/beruby_red.png" width="120" height="auto" class="beruby"></a><div ng-repeat="error in login.errors"><div data-alert="" class="alert-box alert round"><span ng-bind-html="\'form.login_error\' | translate"></span></div></div><form ng-submit="login.submit();"><input ng-model="login.email" required="" type="email" placeholder="{{\'form.email\' | translate}}"> <input ng-model="login.password" required="" type="password" placeholder="{{\'form.password\' | translate}}"><select ng-model="login.country" required=""><option value="" translate="form.country"></option><option ng-repeat="country in countries" value="{{country}}" translate="form.countries.{{country}}"></option></select><button type="submit" class="login-button expand" translate="form.enter"></button></form><a href="#/signup" ng-click=\'loadPath("/signup")\' translate="form.no_account" class="signup-panel"></a> <a href="#/signup" ng-click=\'loadPath("/signup")\' translate="form.signup" class="expand button"></a></div></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/main.html',
    '<nav class="top-bar row"><ul class="title-area"><li class="name"><h1><a href="#">Gulp & Angular</a></h1></li></ul><section class="top-bar-section"><ul class="right"><li class="active"><a ng-href="#">Home</a></li><li><a ng-href="#">About</a></li><li><a ng-href="#">Contact</a></li></ul></section></nav><div class="row"><div class="large-12 large-text-center columns"><div class="panel"><h1>\'Allo, \'Allo!</h1><img src="images/yeoman.png" alt="I\'m Yeoman"><br><p>Always a pleasure scaffolding your apps.</p><p><a class="button radius" ng-href="#">Splendid!</a></p></div></div></div><div class="row"><div class="large-4 columns" ng-repeat="awesomeThing in awesomeThings | orderBy:\'rank\'"><div class="th"><img class="right" ng-src="images/{{awesomeThing.logo}}" alt="{{awesomeThing.title}}"><div class="caption"><h3>{{awesomeThing.title}}</h3><p>{{awesomeThing.description}}</p><p><a ng-href="{{awesomeThing.url}}">{{awesomeThing.url}}</a></p></div></div></div></div><div class="row"><div class="large-12 columns"><hr><p>With ♥ from <a href="https://twitter.com/Swiip">@Swiip</a></p></div></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/navigation.html',
    '<div class="bottom-icon-bar five-up"><a class="item search" ng-class="navigation.active" ng-click="loadPath(\'/search\', true);"><img src="images/menu_search_100.png" ng-hide="navigation.active === \'search\'"> <img src="images/menu_search_active_100.png" ng-show="navigation.active === \'search\'"></a> <a class="item shopping" ng-class="navigation.active" ng-click="loadPath(\'/widgets?section=shopping\', true);"><img src="images/menu_shopping_100.png" ng-hide="navigation.active === \'shopping\'"> <img src="images/menu_shopping_active_100.png" ng-show="navigation.active === \'shopping\'"></a> <a class="item travels" ng-class="navigation.active" ng-click="loadPath(\'/widgets?section=travels\', true);"><img src="images/menu_travels_100.png" ng-hide="navigation.active === \'travels\'"> <img src="images/menu_travels_active_100.png" ng-show="navigation.active === \'travels\'"></a> <a class="item offers" ng-class="navigation.active" ng-click="loadPath(\'/widgets?section=offers\', true);"><img src="images/menu_offers_100.png" ng-hide="navigation.active === \'offers\'"> <img src="images/menu_offers_active_100.png" ng-show="navigation.active === \'offers\'"></a> <a class="item balance" ng-class="navigation.active" ng-click="loadPath(\'/balance\', true);"><img src="images/menu_balance_100.png" ng-hide="navigation.active === \'balance\'"> <img src="images/menu_balance_active_100.png" ng-show="navigation.active === \'balance\'"></a></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/search.html',
    '<div id="search" class="contains-navigation"><ng-include src="\'partials/header.html\'"></ng-include><form class="search row collapse" ng-submit="search.submit();"><div class="small-10 columns"><input type="text" name="query" ng-model="query" class="query" placeholder="{{\'search.placeholder\' | translate}}"></div><div class="small-2 columns"><input type="submit" ng-click="search.submit();" class="button postfix" value=""></div></form><div class="widgets" infinite-scroll="fetchNextPage()" infinite-scroll-distance="2"><a class="row collapse widget" ng-click="loadPath(\'/widgets/{{widget.id}}\');" ng-repeat="widget in search.widgets"><div class="small-2 columns text-center logo-container" style="display:table;height: 60px;"><div style="display:table-cell; vertical-align:middle;"><img ng-src="http://es.beruby.com/{{widget.image_path}}" class="logo"></div></div><div class="small-7 columns" style="display:table;height: 60px; padding-left:1rem;"><div style="display:table-cell; vertical-align:middle;"><p class="name">{{widget.name}}</p></div></div><div class="small-3 columns" style="display:table;height: 60px;"><div style="display:table-cell; vertical-align:middle; text-align: right;"><p class="commission" ng-bind-html="widget.cashback"></p></div></div></a><div class="loading-balls" ng-show="search.fetchingPage"><span class="ball ball-1"></span> <span class="ball ball-2"></span></div></div><div class="row" ng-show="search.widgets.length === 0"><div class="small-12 columns"><br><div ng-show="!search.empty &amp;&amp; !search.hideMessage"><div style="width: 100%; margin: 0 auto;"></div><div><div id="transactions" class="contains-navigation" infinite-scroll="fetchNextPage()" infinite-scroll-distance="2"><div ng-repeat="homeWidget in homeWidgets" class="widgets" ng-show="!transactionsEmpty"><a class="row collapse widget" ng-click="loadPath(\'/widgets/{{homeWidget.id}}\');"><div class="small-2 columns text-center logo-container" style="display:table;height: 60px;"><div style="display:table-cell; vertical-align:middle;"><img ng-src="http://es.beruby.com/{{homeWidget.image_path}}" class="logo"></div></div><div class="small-7 columns" style="display:table;height: 60px; padding-left:1rem;"><div style="display:table-cell; vertical-align:middle;"><p class="name">{{homeWidget.name}}</p></div></div><div class="small-3 columns" style="display:table;height: 60px;"><div style="display:table-cell; vertical-align:middle;text-align: right;"><p class="commission" ng-bind-html="homeWidget.payment"></p></div></div></a></div></div></div></div><br><div class="panel empty" ng-show="search.empty" translate="search.empty"></div></div></div><ng-include src="\'partials/navigation.html\'"></ng-include></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/show_widget.html',
    '<div id="show-widget" class="contains-navigation section-{{widget.section}}"><ng-include src="\'partials/header.html\'"></ng-include><div class="content"><br><div class="row collapse" style="padding:0.9375rem;"><div ng-show="widget.imagePath" class="logo_summary"><img ng-src="http://es.beruby.com/{{widget.imagePath}}" class="logo"></div>{{widget.summary}}</div><br><div class="row visit_button"><div class="small-12 columns"><a ng-click="visit();" translate="widget.visit" class="visit-button" ng-show="widget.name"></a></div></div><div class="row" ng-show="widget.earnings.length > 0"><div class="small-12 columns"><table ng-if="widget.type === \'sale\'" class="earnings"><tr><th translate="widget.concept"></th><th translate="widget.cashback"></th></tr><tr ng-repeat="earning in widget.earnings"><td ng-bind-html="earning.concept"></td><td ng-bind-html="earning.direct_earning"></td></tr></table><table ng-if="widget.type === \'no_sale\'" class="earnings"><tr><th translate="widget.concept"></th><th translate="widget.direct_amount"></th><th translate="widget.network_amount"></th></tr><tr ng-repeat="earning in widget.earnings"><td ng-bind-html="earning.concept"></td><td ng-bind-html="earning.direct_earning"></td><td ng-bind-html="earning.network_earning"></td></tr></table></div></div><div class="row"><div class="small-12 columns"><div data-alert="" class="alert-box warning radius"><span translate="widget.warning"></span></div></div></div><div class="row" ng-show="widget.particularConditions"><div class="small-12 columns"><h3 translate="widget.particular_conditions"></h3><span ng-bind-html="widget.particularConditions"></span></div></div><div class="row" ng-show="widget.products"><div class="small-12 columns"><h3 translate="widget.products"></h3><span ng-bind-html="widget.products"></span></div></div><div class="row" ng-show="widget.monetize"><div class="small-12 columns"><h3 translate="widget.monetize"></h3><span ng-bind-html="widget.monetize"></span></div></div><div class="row" ng-show="widget.related"><div class="small-12 columns"><h3 translate="widget.related"></h3><span ng-bind-html="widget.related"></span></div></div></div><br><br><br><br><ng-include src="\'partials/navigation.html\'"></ng-include></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/signup.html',
    '<div id="signup" class="row"><div class="small-12 columns"><a href="#/"><img src="images/beruby_red.png" width="120" height="auto" class="beruby"></a><form ng-submit="signup.submit();"><input type="text" placeholder="{{\'form.name\' | translate}}" ng-model="signup.name" ng-class="{error: signup.errors.name}"> <small class="error" ng-show="signup.errors.name">{{signup.errors.name}}</small> <input type="email" placeholder="{{\'form.email\' | translate}}" ng-model="signup.email" ng-class="{error: signup.errors.email}"> <small class="error" ng-show="signup.errors.email">{{signup.errors.email}}</small> <input type="password" placeholder="{{\'form.password\' | translate}}" ng-model="signup.password" ng-class="{error: signup.errors.password}"> <small class="error" ng-show="signup.errors.password">{{signup.errors.password}}</small><select ng-model="signup.country" required=""><option value="" translate="form.country"></option><option ng-repeat="country in countries" value="{{country}}" translate="form.countries.{{country}}"></option></select><button type="submit" translate="form.signup" class="expand"></button></form></div></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/transactions.html',
    '<div id="transactions" class="contains-navigation" infinite-scroll="fetchNextPage()" infinite-scroll-distance="2"><ng-include src="\'partials/header.html\'"></ng-include><div ng-repeat="transaction in transactions" class="transaction" ng-show="!transactionsEmpty"><div class="row"><div class="small-12 columns"><img class="image" ng-src="http://es1.beruby.com{{transaction.image}}" width="16px"> <span class="concept">{{transaction.concept}}</span></div></div><div class="row info"><div class="small-6 columns date">{{transaction.date}}</div><div class="small-6 columns text-right amount" ng-class="transaction.negative" ng-bind-html="transaction.amount"></div></div></div><div class="row" ng-show="transactionsEmpty"><div class="small-12 columns"><br><div class="panel" translate="transactions.empty"></div></div></div><div class="loading-balls" ng-show="fetchingPage"><span class="ball ball-1"></span> <span class="ball ball-2"></span></div><ng-include src="\'partials/navigation.html\'"></ng-include></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/welcome.html',
    '<div id="welcome" class="row" ng-switch="" on="welcome.currentId" ng-class="[welcome.animate]" ng-swipe-right="welcome.swipeRight()" ng-swipe-left="welcome.swipeLeft()"><div class="text-center small-12 columns slide travels" ng-switch-when="1"><h1>beruby</h1><img class="image" src="images/tutorial_travels.png"><h2 translate="welcome.travels_title"></h2><p translate="welcome.travels_phrase"></p><div class="dots"><div class="dot"></div><div class="dot selected"></div><div class="dot"></div></div><button class="submit" ng-click="welcome.submit();" translate="welcome.start"></button></div><div class="text-center small-12 columns slide offers" ng-switch-when="2"><h1>beruby</h1><img class="image" src="images/tutorial_offers.png"><h2 translate="welcome.offers_title"></h2><p translate="welcome.offers_phrase"></p><div class="dots"><div class="dot"></div><div class="dot"></div><div class="dot selected"></div></div><button class="submit" ng-click="welcome.submit();" translate="welcome.start"></button></div><div class="text-center small-12 columns slide shopping" ng-switch-default=""><h1>beruby</h1><img class="image" src="images/tutorial_shopping.png"><h2 translate="welcome.shopping_title"></h2><p translate="welcome.shopping_phrase"></p><div class="dots"><div class="dot selected"></div><div class="dot"></div><div class="dot"></div></div><button class="submit" ng-click="welcome.submit();" translate="welcome.start"></button></div></div>');
}]);
})();

(function(module) {
try {
  module = angular.module('beruby');
} catch (e) {
  module = angular.module('beruby', []);
}
module.run(['$templateCache', function($templateCache) {
  $templateCache.put('partials/widgets_section.html',
    '<div id="section-{{section.name}}" class="widgets-section contains-navigation"><ng-include src="\'partials/header.html\'"></ng-include><div class="row"><ul class="categories small-block-grid-1 medium-block-grid-2 large-block-grid-3" style="width: 100%;padding: 0px;margin: 0px;"><li ng-repeat="category in section.categories" style="padding:0px;margin:0px;"><a class="" ng-click="loadPath(\'/category?name={{category.name | encodeURIComponent}}&amp;section={{section.name}}&amp;url={{category.url | encodeURIComponent}}\');"><div class="categories row collapse"><div class="small-6 columns" style="background-image: url(\'images/categories/{{category.name_id}}.jpg\'); height: 10rem;width: 100%;background-size: cover;"><div style="position: absolute; bottom:0px;background-color: rgba(0,0,0,0.4);width: 100%" class="category">{{category.name}}</div></div></div></a></li></ul></div></div><ng-include src="\'partials/navigation.html\'"></ng-include>');
}]);
})();
